# Reference

<!-- DO NOT EDIT: This document was generated by Puppet Strings -->

## Table of Contents

### Classes

* [`minio`](#minio): Manages a Minio installation on various Linux/BSD operating systems.
* [`minio::client`](#minioclient): Manages a Minio client (mc) on various Linux/BSD operating systems.
* [`minio::client::config`](#minioclientconfig): Manages a Minio client (mc) configuration various Linux/BSD operating systems.
* [`minio::client::install`](#minioclientinstall): Manages a Minio client (mc) installation various Linux/BSD operating systems.
* [`minio::server`](#minioserver): Manages a Minio server installation on various Linux/BSD operating systems.
* [`minio::server::certs`](#minioservercerts): Manages minio certificate deployment.
* [`minio::server::config`](#minioserverconfig): Applies configuration for `::minio::server` class to system.
* [`minio::server::install`](#minioserverinstall): Installs minio server and required service definitions.
* [`minio::server::service`](#minioserverservice): Manages services for the `::minio::server` class.
* [`minio::server::user`](#minioserveruser): Manages user for the minio server installations.

### Resource types

* [`minio_client_alias`](#minio_client_alias): Manages minio client aliases

## Classes

### <a name="minio"></a>`minio`

Copyright
---------

Copyright 2017-2021 Daniel S. Reichenbach <https://kogitoapp.com>

#### Examples

##### 

```puppet
class { 'minio':
    package_ensure                => 'present',
    owner                         => 'minio',
    group                         => 'minio',
    base_url                      => 'https://dl.minio.io/server/minio/release',
    version                       => 'RELEASE.2021-08-20T18-32-01Z',
    checksum                      => '0bf72d6fd0a88fee35ac598a1e7a5c90c78b53b6db3988414e34535fb6cf420c',
    checksum_type                 => 'sha256',
    configuration_directory       => '/etc/minio',
    installation_directory        => '/opt/minio',
    storage_root                  => '/var/minio',
    listen_ip                     => '127.0.0.1',
    listen_port                   => 9000,
    configuration                 => {
        'MINIO_ROOT_USER'     => 'admin',
        'MINIO_ROOT_PASSWORD' => 'password',
        'MINIO_REGION_NAME'   => 'us-east-1',
    },
    manage_service                => true,
    service_template              => 'minio/systemd.erb',
    service_provider              => 'systemd',
    service_ensure                => 'running',
    manage_server_installation    => true,
    manage_client_installation    => true,
    client_package_ensure         => 'present',
    client_base_url               => 'https://dl.minio.io/client/mc/release',
    client_version                => 'RELEASE.2021-07-27T06-46-19Z',
    client_checksum               => '0df81285771e12e16a0c4c2f5e0ebc700e66abb8179013cc740d48b0abad49be',
    client_checksum_type          => 'sha256',
    client_installation_directory => '/opt/minioclient',
    cert_ensure                   => 'present',
    cert_directory                => '/etc/minio/certs',
    default_cert_name             => 'miniodefault',
    default_cert_configuration    => {
      'source_path'      => 'puppet:///modules/minio/examples',
      'source_cert_name' => 'localhost',
      'source_key_name'  => 'localhost',
    },
    additional_certs              => {
      'example' => {
        'source_path'      => 'puppet:///modules/minio/examples',
        'source_cert_name' => 'example.test',
        'source_key_name'  => 'example.test',
      }
    },
    custom_configuration_file_path => '/etc/default/minio',
}
```

#### Parameters

The following parameters are available in the `minio` class:

* [`package_ensure`](#package_ensure)
* [`manage_user`](#manage_user)
* [`manage_group`](#manage_group)
* [`manage_home`](#manage_home)
* [`owner`](#owner)
* [`group`](#group)
* [`home`](#home)
* [`base_url`](#base_url)
* [`version`](#version)
* [`checksum`](#checksum)
* [`checksum_type`](#checksum_type)
* [`configuration_directory`](#configuration_directory)
* [`installation_directory`](#installation_directory)
* [`storage_root`](#storage_root)
* [`listen_ip`](#listen_ip)
* [`listen_port`](#listen_port)
* [`configuration`](#configuration)
* [`manage_service`](#manage_service)
* [`service_ensure`](#service_ensure)
* [`service_template`](#service_template)
* [`service_provider`](#service_provider)
* [`manage_server_installation`](#manage_server_installation)
* [`manage_client_installation`](#manage_client_installation)
* [`client_package_ensure`](#client_package_ensure)
* [`client_base_url`](#client_base_url)
* [`client_version`](#client_version)
* [`client_checksum`](#client_checksum)
* [`client_checksum_type`](#client_checksum_type)
* [`client_installation_directory`](#client_installation_directory)
* [`client_binary_name`](#client_binary_name)
* [`client_aliases`](#client_aliases)
* [`purge_unmanaged_client_aliases`](#purge_unmanaged_client_aliases)
* [`cert_ensure`](#cert_ensure)
* [`cert_directory`](#cert_directory)
* [`default_cert_name`](#default_cert_name)
* [`default_cert_configuration`](#default_cert_configuration)
* [`additional_certs`](#additional_certs)
* [`custom_configuration_file_path`](#custom_configuration_file_path)

##### <a name="package_ensure"></a>`package_ensure`

Data type: `Enum['present', 'absent']`

Decides if the `minio` binary will be installed. Default: `present`

##### <a name="manage_user"></a>`manage_user`

Data type: `Boolean`

Should we manage provisioning the user? Default: `true`

##### <a name="manage_group"></a>`manage_group`

Data type: `Boolean`

Should we manage provisioning the group? Default: `true`

##### <a name="manage_home"></a>`manage_home`

Data type: `Boolean`

Should we manage provisioning the home directory? Default: `true`

##### <a name="owner"></a>`owner`

Data type: `String`

The user owning minio and its' files. Default: 'minio'

##### <a name="group"></a>`group`

Data type: `String`

The group owning minio and its' files. Default: 'minio'

##### <a name="home"></a>`home`

Data type: `Optional[Stdlib::Absolutepath]`

Qualified path to the users' home directory. Default: empty

##### <a name="base_url"></a>`base_url`

Data type: `Stdlib::HTTPUrl`

Download base URL for the server. Default: Github. Can be used for local mirrors.

##### <a name="version"></a>`version`

Data type: `String`

Server release version to be installed.

##### <a name="checksum"></a>`checksum`

Data type: `String`

Checksum for the server binary.

##### <a name="checksum_type"></a>`checksum_type`

Data type: `String`

Type of checksum used to verify the server binary being installed. Default: `sha256`

##### <a name="configuration_directory"></a>`configuration_directory`

Data type: `Stdlib::Absolutepath`

Directory holding Minio configuration file. Default: `/etc/minio`

##### <a name="installation_directory"></a>`installation_directory`

Data type: `Stdlib::Absolutepath`

Target directory to hold the minio installation. Default: `/opt/minio`

##### <a name="storage_root"></a>`storage_root`

Data type: `Variant[Stdlib::Absolutepath, Array[Stdlib::Absolutepath]]`

Directory or directories where minio will keep all data. Default: `/var/minio`

##### <a name="listen_ip"></a>`listen_ip`

Data type: `Stdlib::IP::Address`

IP address on which Minio should listen to requests.

##### <a name="listen_port"></a>`listen_port`

Data type: `Stdlib::Port`

Port on which Minio should listen to requests.

##### <a name="configuration"></a>`configuration`

Data type: `Hash[String[1], Variant[String, Integer]]`

Hash with environment settings for Minio.

##### <a name="manage_service"></a>`manage_service`

Data type: `Boolean`

Should we manage a server service definition for Minio? Default: `true`

##### <a name="service_ensure"></a>`service_ensure`

Data type: `Stdlib::Ensure::Service`

Defines the state of the minio server service. Default: `running`

##### <a name="service_template"></a>`service_template`

Data type: `String`

Path to the server service template file.

##### <a name="service_provider"></a>`service_provider`

Data type: `String`

Which service provider do we use?

##### <a name="manage_server_installation"></a>`manage_server_installation`

Data type: `Boolean`

Decides if puppet should manage the minio server installation.

##### <a name="manage_client_installation"></a>`manage_client_installation`

Data type: `Boolean`

Decides if puppet should manage the minio client installation.

##### <a name="client_package_ensure"></a>`client_package_ensure`

Data type: `Enum['present', 'absent']`

Decides if the `mc` client binary will be installed. Default: `present`

##### <a name="client_base_url"></a>`client_base_url`

Data type: `Stdlib::HTTPUrl`

Download base URL for the minio client. Default: Github. Can be used for local mirrors.

##### <a name="client_version"></a>`client_version`

Data type: `String`

Client release version to be installed.

##### <a name="client_checksum"></a>`client_checksum`

Data type: `String`

Checksum for the client binary.

##### <a name="client_checksum_type"></a>`client_checksum_type`

Data type: `String`

Type of checksum used to verify the client binary being installed. Default: `sha256`

##### <a name="client_installation_directory"></a>`client_installation_directory`

Data type: `Stdlib::Absolutepath`

Target directory to hold the minio client installation. Default: `/opt/minioclient`

##### <a name="client_binary_name"></a>`client_binary_name`

Data type: `String`

Target name of the minio client binary. Use this to avoid collisions with another `mc`.

##### <a name="client_aliases"></a>`client_aliases`

Data type: `Hash`

List of aliases to add to the minio client configuration. For parameter description see `minio_client_alias`.

##### <a name="purge_unmanaged_client_aliases"></a>`purge_unmanaged_client_aliases`

Data type: `Boolean`

Decides if puppet should purge unmanaged minio client aliases

##### <a name="cert_ensure"></a>`cert_ensure`

Data type: `Enum['present', 'absent']`

Decides if minio certificates binary will be installed.

##### <a name="cert_directory"></a>`cert_directory`

Data type: `Stdlib::Absolutepath`

Directory where minio will keep all cerfiticates.

##### <a name="default_cert_name"></a>`default_cert_name`

Data type: `Optional[String[1]]`

Name of the default certificate. If no value provided, `miniodefault` is going
to be used.

##### <a name="default_cert_configuration"></a>`default_cert_configuration`

Data type: `Optional[Hash]`

Hash with the configuration for the default certificate. See `certs::site`
of the `broadinstitute/certs` module for parameter descriptions.

##### <a name="additional_certs"></a>`additional_certs`

Data type: `Optional[Hash]`

Hash of the additional certificates to deploy. The key is a directory name, value is
a hash of certificate configuration. See `certs::site` of the `broadinstitute/certs`
module for parameter descriptions. **Important**: if you use additional certificates,
their corresponding SAN names should be filled for SNI to work.

##### <a name="custom_configuration_file_path"></a>`custom_configuration_file_path`

Data type: `Optional[Stdlib::Absolutepath]`

Optional custom location of the minio environment file.

### <a name="minioclient"></a>`minio::client`

Manages a Minio client (mc) on various Linux/BSD operating systems.

#### Examples

##### 

```puppet
class { 'minio::client':
    manage_client_installation => true,
    package_ensure             => 'present',
    base_url                   => 'https://dl.minio.io/client/mc/release',
    version                    => 'RELEASE.2021-07-27T06-46-19Z',
    checksum                   => '0df81285771e12e16a0c4c2f5e0ebc700e66abb8179013cc740d48b0abad49be',
    checksum_type              => 'sha256',
    installation_directory     => '/usr/local/bin',
    binary_name                => 'minio-client',
    aliases                    => {
      'default' => {
        'ensure'              => 'present',
        'endpoint'            => 'http://localhost:9000',
        'access_key'          => 'admin',
        'secret_key'          => Sensitive('password'), # can also be a string
        'api_signature'       => 'S3v4', # optional
        'path_lookup_support' => 'on',   # optional
      }
    },
    purge_unmanaged_aliases    => true
}
```

#### Parameters

The following parameters are available in the `minio::client` class:

* [`manage_client_installation`](#manage_client_installation)
* [`package_ensure`](#package_ensure)
* [`base_url`](#base_url)
* [`version`](#version)
* [`checksum`](#checksum)
* [`checksum_type`](#checksum_type)
* [`installation_directory`](#installation_directory)
* [`aliases`](#aliases)
* [`purge_unmanaged_aliases`](#purge_unmanaged_aliases)
* [`binary_name`](#binary_name)

##### <a name="manage_client_installation"></a>`manage_client_installation`

Data type: `Boolean`

Decides if puppet should manage the minio client installation.

Default value: `$minio::manage_client_installation`

##### <a name="package_ensure"></a>`package_ensure`

Data type: `Enum['present', 'absent']`

Decides if the `mc` client binary will be installed. Default: `present`

Default value: `$minio::client_package_ensure`

##### <a name="base_url"></a>`base_url`

Data type: `Stdlib::HTTPUrl`

Download base URL for the minio client. Default: Github. Can be used for local mirrors.

Default value: `$minio::client_base_url`

##### <a name="version"></a>`version`

Data type: `String`

Client release version to be installed.

Default value: `$minio::client_version`

##### <a name="checksum"></a>`checksum`

Data type: `String`

Checksum for the client binary.

Default value: `$minio::client_checksum`

##### <a name="checksum_type"></a>`checksum_type`

Data type: `String`

Type of checksum used to verify the client binary being installed. Default: `sha256`

Default value: `$minio::client_checksum_type`

##### <a name="installation_directory"></a>`installation_directory`

Data type: `Stdlib::Absolutepath`

Target directory to hold the minio client installation. Default: `/opt/minioclient`

Default value: `$minio::client_installation_directory`

##### <a name="aliases"></a>`aliases`

Data type: `Hash`

List of aliases to add to the minio client configuration. For parameter description see `minio_client_alias`.

Default value: `$minio::client_aliases`

##### <a name="purge_unmanaged_aliases"></a>`purge_unmanaged_aliases`

Data type: `Boolean`

Decides if puppet should purge unmanaged minio client aliases

Default value: `$minio::purge_unmanaged_client_aliases`

##### <a name="binary_name"></a>`binary_name`

Data type: `String`



Default value: `$minio::client_binary_name`

### <a name="minioclientconfig"></a>`minio::client::config`

Manages a Minio client (mc) configuration various Linux/BSD operating systems.

#### Examples

##### 

```puppet
class { 'minio::client::config':
    aliases                 => {
      'default' => {
        'ensure'              => 'present',
        'endpoint'            => 'http://localhost:9000',
        'access_key'          => 'admin',
        'secret_key'          => Sensitive('password'), # can also be a string
        'api_signature'       => 'S3v4', # optional
        'path_lookup_support' =>'on',    # optional
      }
    },
    purge_unmanaged_aliases => true
}
```

#### Parameters

The following parameters are available in the `minio::client::config` class:

* [`aliases`](#aliases)
* [`purge_unmanaged_aliases`](#purge_unmanaged_aliases)

##### <a name="aliases"></a>`aliases`

Data type: `Hash`

List of aliases to add to the minio client configuration. For parameter description see `minio_client_alias`.

Default value: `$minio::client::aliases`

##### <a name="purge_unmanaged_aliases"></a>`purge_unmanaged_aliases`

Data type: `Boolean`

Decides if puppet should purge unmanaged minio client aliases

Default value: `$minio::client::purge_unmanaged_aliases`

### <a name="minioclientinstall"></a>`minio::client::install`

Manages a Minio client (mc) installation various Linux/BSD operating systems.

#### Examples

##### 

```puppet
class { 'minio::client::install':
    package_ensure         => 'present',
    base_url               => 'https://dl.minio.io/client/mc/release',
    version                => 'RELEASE.2021-07-27T06-46-19Z',
    checksum               => '0df81285771e12e16a0c4c2f5e0ebc700e66abb8179013cc740d48b0abad49be',
    checksum_type          => 'sha256',
    installation_directory => '/usr/local/bin',
    binary_name            => 'minio-client'
}
```

#### Parameters

The following parameters are available in the `minio::client::install` class:

* [`package_ensure`](#package_ensure)
* [`base_url`](#base_url)
* [`version`](#version)
* [`checksum`](#checksum)
* [`checksum_type`](#checksum_type)
* [`installation_directory`](#installation_directory)
* [`binary_name`](#binary_name)

##### <a name="package_ensure"></a>`package_ensure`

Data type: `Enum['present', 'absent']`

Decides if the `mc` client binary will be installed. Default: `present`

Default value: `$minio::client::package_ensure`

##### <a name="base_url"></a>`base_url`

Data type: `Stdlib::HTTPUrl`

Download base URL for the minio client. Default: Github. Can be used for local mirrors.

Default value: `$minio::client::base_url`

##### <a name="version"></a>`version`

Data type: `String`

Client release version to be installed.

Default value: `$minio::client::version`

##### <a name="checksum"></a>`checksum`

Data type: `String`

Checksum for the client binary.

Default value: `$minio::client::checksum`

##### <a name="checksum_type"></a>`checksum_type`

Data type: `String`

Type of checksum used to verify the client binary being installed. Default: `sha256`

Default value: `$minio::client::checksum_type`

##### <a name="installation_directory"></a>`installation_directory`

Data type: `Stdlib::Absolutepath`

Target directory to hold the minio client installation. Default: `/opt/minioclient`

Default value: `$minio::client::installation_directory`

##### <a name="binary_name"></a>`binary_name`

Data type: `String`



Default value: `$minio::client::binary_name`

### <a name="minioserver"></a>`minio::server`

Copyright
---------

Copyright 2017-2021 Daniel S. Reichenbach <https://kogitoapp.com>

#### Examples

##### 

```puppet
class { 'minio::server':
    manage_server_installation     => true,
    package_ensure                 => 'present',
    owner                          => 'minio',
    group                          => 'minio',
    base_url                       => 'https://dl.minio.io/server/minio/release',
    version                        => 'RELEASE.2021-08-20T18-32-01Z',
    checksum                       => '0bf72d6fd0a88fee35ac598a1e7a5c90c78b53b6db3988414e34535fb6cf420c',
    checksum_type                  => 'sha256',
    configuration_directory        => '/etc/minio',
    installation_directory         => '/opt/minio',
    storage_root                   => '/var/minio', # Could also be an array
    listen_ip                      => '127.0.0.1',
    listen_port                    => 9000,
    configuration                  => {
        'MINIO_ROOT_USER'     => 'admin',
        'MINIO_ROOT_PASSWORD' => 'password',
        'MINIO_REGION_NAME'   => 'us-east-1',
    },
    manage_service                 => true,
    service_template               => 'minio/systemd.erb',
    service_provider               => 'systemd',
    service_ensure                 => 'running',
    cert_ensure                    => 'present',
    cert_directory                 => '/etc/minio/certs',
    default_cert_name              => 'miniodefault',
    default_cert_configuration     => {
      'source_path'      => 'puppet:///modules/minio/examples',
      'source_cert_name' => 'localhost',
      'source_key_name'  => 'localhost',
    },
    additional_certs               => {
      'example' => {
        'source_path'      => 'puppet:///modules/minio/examples',
        'source_cert_name' => 'example.test',
        'source_key_name'  => 'example.test',
      }
    },
    custom_configuration_file_path => '/etc/default/minio',
}
```

#### Parameters

The following parameters are available in the `minio::server` class:

* [`manage_server_installation`](#manage_server_installation)
* [`package_ensure`](#package_ensure)
* [`manage_user`](#manage_user)
* [`manage_group`](#manage_group)
* [`manage_home`](#manage_home)
* [`owner`](#owner)
* [`group`](#group)
* [`base_url`](#base_url)
* [`home`](#home)
* [`base_url`](#base_url)
* [`version`](#version)
* [`checksum`](#checksum)
* [`checksum_type`](#checksum_type)
* [`configuration_directory`](#configuration_directory)
* [`installation_directory`](#installation_directory)
* [`storage_root`](#storage_root)
* [`listen_ip`](#listen_ip)
* [`listen_port`](#listen_port)
* [`configuration`](#configuration)
* [`manage_service`](#manage_service)
* [`service_ensure`](#service_ensure)
* [`service_template`](#service_template)
* [`service_provider`](#service_provider)
* [`cert_ensure`](#cert_ensure)
* [`cert_directory`](#cert_directory)
* [`default_cert_name`](#default_cert_name)
* [`default_cert_configuration`](#default_cert_configuration)
* [`additional_certs`](#additional_certs)
* [`custom_configuration_file_path`](#custom_configuration_file_path)

##### <a name="manage_server_installation"></a>`manage_server_installation`

Data type: `Boolean`

Decides if puppet should manage the minio server installation.

Default value: `$minio::manage_server_installation`

##### <a name="package_ensure"></a>`package_ensure`

Data type: `Enum['present', 'absent']`

Decides if the `minio` binary will be installed. Default: `present`

Default value: `$minio::package_ensure`

##### <a name="manage_user"></a>`manage_user`

Data type: `Boolean`

Should we manage provisioning the user? Default: `true`

Default value: `$minio::manage_user`

##### <a name="manage_group"></a>`manage_group`

Data type: `Boolean`

Should we manage provisioning the group? Default: `true`

Default value: `$minio::manage_group`

##### <a name="manage_home"></a>`manage_home`

Data type: `Boolean`

Should we manage provisioning the home directory? Default: `true`

Default value: `$minio::manage_home`

##### <a name="owner"></a>`owner`

Data type: `String`

The user owning minio and its' files. Default: 'minio'

Default value: `$minio::owner`

##### <a name="group"></a>`group`

Data type: `String`

The group owning minio and its' files. Default: 'minio'

Default value: `$minio::group`

##### <a name="base_url"></a>`base_url`

Data type: `Stdlib::HTTPUrl`

Download base URL for the server. Can be used for local mirrors.

Default value: `$minio::base_url`

##### <a name="home"></a>`home`

Data type: `Optional[Stdlib::Absolutepath]`

Qualified path to the users' home directory. Default: empty

Default value: `$minio::home`

##### <a name="base_url"></a>`base_url`

Data type: `Stdlib::HTTPUrl`

Download base URL for the server. Default: Github. Can be used for local mirrors.

Default value: `$minio::base_url`

##### <a name="version"></a>`version`

Data type: `String`

Release version to be installed.

Default value: `$minio::version`

##### <a name="checksum"></a>`checksum`

Data type: `String`

Checksum for the binary.

Default value: `$minio::checksum`

##### <a name="checksum_type"></a>`checksum_type`

Data type: `String`

Type of checksum used to verify the binary being installed. Default: `sha256`

Default value: `$minio::checksum_type`

##### <a name="configuration_directory"></a>`configuration_directory`

Data type: `Stdlib::Absolutepath`

Directory holding Minio configuration file. Default: `/etc/minio`

Default value: `$minio::configuration_directory`

##### <a name="installation_directory"></a>`installation_directory`

Data type: `Stdlib::Absolutepath`

Target directory to hold the minio installation. Default: `/opt/minio`

Default value: `$minio::installation_directory`

##### <a name="storage_root"></a>`storage_root`

Data type: `Variant[Stdlib::Absolutepath, Array[Stdlib::Absolutepath]]`

Directory or directories where minio will keep all data. Default: `/var/minio`

Default value: `$minio::storage_root`

##### <a name="listen_ip"></a>`listen_ip`

Data type: `Stdlib::IP::Address`

IP address on which Minio should listen to requests.

Default value: `$minio::listen_ip`

##### <a name="listen_port"></a>`listen_port`

Data type: `Stdlib::Port`

Port on which Minio should listen to requests.

Default value: `$minio::listen_port`

##### <a name="configuration"></a>`configuration`

Data type: `Hash[String[1], Variant[String, Integer]]`

Hash with environment settings for Minio.

Default value: `$minio::configuration`

##### <a name="manage_service"></a>`manage_service`

Data type: `Boolean`

Should we manage a server service definition for Minio? Default: `true`

Default value: `$minio::manage_service`

##### <a name="service_ensure"></a>`service_ensure`

Data type: `Stdlib::Ensure::Service`

Defines the state of the minio server service. Default: `running`

Default value: `$minio::service_ensure`

##### <a name="service_template"></a>`service_template`

Data type: `String`

Path to the server service template file.

Default value: `$minio::service_template`

##### <a name="service_provider"></a>`service_provider`

Data type: `String`

Which service provider do we use?

Default value: `$minio::service_provider`

##### <a name="cert_ensure"></a>`cert_ensure`

Data type: `Enum['present', 'absent']`

Decides if minio certificates binary will be installed.

Default value: `$minio::cert_ensure`

##### <a name="cert_directory"></a>`cert_directory`

Data type: `Stdlib::Absolutepath`

Directory where minio will keep all cerfiticates.

Default value: `$minio::cert_directory`

##### <a name="default_cert_name"></a>`default_cert_name`

Data type: `Optional[String[1]]`

Name of the default certificate. If no value provided, `miniodefault` is going
to be used.

Default value: `$minio::default_cert_name`

##### <a name="default_cert_configuration"></a>`default_cert_configuration`

Data type: `Optional[Hash]`

Hash with the configuration for the default certificate. See `certs::site`
of the `broadinstitute/certs` module for parameter descriptions.

Default value: `$minio::default_cert_configuration`

##### <a name="additional_certs"></a>`additional_certs`

Data type: `Optional[Hash]`

Hash of the additional certificates to deploy. The key is a directory name, value is
a hash of certificate configuration. See `certs::site` of the `broadinstitute/certs`
module for parameter descriptions. **Important**: if you use additional certificates,
their corresponding SAN names should be filled for SNI to work.

Default value: `$minio::additional_certs`

##### <a name="custom_configuration_file_path"></a>`custom_configuration_file_path`

Data type: `Optional[Stdlib::Absolutepath]`

Optional custom location of the minio environment file.

Default value: `$minio::custom_configuration_file_path`

### <a name="minioservercerts"></a>`minio::server::certs`

Manages minio certificate deployment.

#### Examples

##### 

```puppet
class {'minio::server::certs':
  cert_ensure                => 'present',
  owner                      => 'minio',
  group                      => 'minio',
  cert_directory             => '/etc/minio/certs',
  default_cert_name          => 'miniodefault',
  default_cert_configuration => {
    'source_path'      => 'puppet:///modules/minio/examples',
    'source_cert_name' => 'localhost',
    'source_key_name'  => 'localhost',
  },

  additional_certs           => {
    'example' => {
      'source_path'      => 'puppet:///modules/minio/examples',
      'source_cert_name' => 'example.test',
      'source_key_name'  => 'example.test',
    }
  }
}
```

#### Parameters

The following parameters are available in the `minio::server::certs` class:

* [`cert_ensure`](#cert_ensure)
* [`owner`](#owner)
* [`group`](#group)
* [`cert_directory`](#cert_directory)
* [`default_cert_name`](#default_cert_name)
* [`default_cert_configuration`](#default_cert_configuration)
* [`additional_certs`](#additional_certs)

##### <a name="cert_ensure"></a>`cert_ensure`

Data type: `Enum['present', 'absent']`

Decides if minio certificates binary will be installed.

Default value: `$minio::server::cert_ensure`

##### <a name="owner"></a>`owner`

Data type: `String`

The user owning minio cerfificates.

Default value: `$minio::server::owner`

##### <a name="group"></a>`group`

Data type: `String`

The group owning minio certificates.

Default value: `$minio::server::group`

##### <a name="cert_directory"></a>`cert_directory`

Data type: `Stdlib::Absolutepath`

Directory where minio will keep all cerfiticates.

Default value: `$minio::server::cert_directory`

##### <a name="default_cert_name"></a>`default_cert_name`

Data type: `Optional[String[1]]`

Name of the default certificate. If no value provided, `miniodefault` is going
to be used.

Default value: `$minio::server::default_cert_name`

##### <a name="default_cert_configuration"></a>`default_cert_configuration`

Data type: `Optional[Hash]`

Hash with the configuration for the default certificate. See `certs::site`
of the `broadinstitute/certs` module for parameter descriptions.

Default value: `$minio::server::default_cert_configuration`

##### <a name="additional_certs"></a>`additional_certs`

Data type: `Optional[Hash]`

Hash of the additional certificates to deploy. The key is a directory name, value is
a hash of certificate configuration. See `certs::site` of the `broadinstitute/certs`
module for parameter descriptions. **Important**: if you use additional certificates,
their corresponding SAN names should be filled for SNI to work.

Default value: `$minio::server::additional_certs`

### <a name="minioserverconfig"></a>`minio::server::config`

Copyright
---------

Copyright 2017-2021 Daniel S. Reichenbach <https://kogitoapp.com>

#### Examples

##### 

```puppet
class { 'minio::server::config':
    owner                          => 'minio',
    group                          => 'minio',
    configuration_directory        => '/etc/minio',
    installation_directory         => '/opt/minio',
    storage_root                   => '/var/minio',
    configuration                  => {
        'MINIO_ROOT_USER'     => 'admin',
        'MINIO_ROOT_PASSWORD' => 'password',
        'MINIO_REGION_NAME'   => 'us-east-1',
    },
    custom_configuration_file_path => '/etc/default/minio',
}
```

#### Parameters

The following parameters are available in the `minio::server::config` class:

* [`owner`](#owner)
* [`group`](#group)
* [`configuration_directory`](#configuration_directory)
* [`installation_directory`](#installation_directory)
* [`storage_root`](#storage_root)
* [`configuration`](#configuration)
* [`custom_configuration_file_path`](#custom_configuration_file_path)

##### <a name="owner"></a>`owner`

Data type: `String`

The user owning minio and its' files.

Default value: `$minio::server::owner`

##### <a name="group"></a>`group`

Data type: `String`

The group owning minio and its' files.

Default value: `$minio::server::group`

##### <a name="configuration_directory"></a>`configuration_directory`

Data type: `Stdlib::Absolutepath`

Directory holding Minio configuration file./minio`

Default value: `$minio::server::configuration_directory`

##### <a name="installation_directory"></a>`installation_directory`

Data type: `Stdlib::Absolutepath`

Target directory to hold the minio installation./minio`

Default value: `$minio::server::installation_directory`

##### <a name="storage_root"></a>`storage_root`

Data type: `Variant[Stdlib::Absolutepath, Array[Stdlib::Absolutepath]]`

Directory or directories where minio will keep all data.

Default value: `$minio::server::storage_root`

##### <a name="configuration"></a>`configuration`

Data type: `Hash[String[1], Variant[String, Integer]]`

Hash with environment settings for Minio.

Default value: `$minio::server::configuration`

##### <a name="custom_configuration_file_path"></a>`custom_configuration_file_path`

Data type: `Optional[Stdlib::Absolutepath]`

Optional custom location of the minio environment file.

Default value: `$minio::server::custom_configuration_file_path`

### <a name="minioserverinstall"></a>`minio::server::install`

Copyright
---------

Copyright 2017-2021 Daniel S. Reichenbach <https://kogitoapp.com>

#### Examples

##### 

```puppet
class { 'minio::server::install':
    package_ensure                 => 'present',
    owner                          => 'minio',
    group                          => 'minio',
    base_url                       => 'https://dl.minio.io/server/minio/release',
    version                        => 'RELEASE.2021-08-20T18-32-01Z',
    checksum                       => '0bf72d6fd0a88fee35ac598a1e7a5c90c78b53b6db3988414e34535fb6cf420c',
    checksum_type                  => 'sha256',
    configuration_directory        => '/etc/minio',
    installation_directory         => '/opt/minio',
    storage_root                   => '/var/minio',
    listen_ip                      => '127.0.0.1',
    listen_port                    => 9000,
    manage_service                 => true,
    service_template               => 'minio/systemd.erb',
    service_provider               => 'systemd',
    cert_directory                 => '/etc/minio/certs',
    custom_configuration_file_path => '/etc/default/minio',
}
```

#### Parameters

The following parameters are available in the `minio::server::install` class:

* [`package_ensure`](#package_ensure)
* [`owner`](#owner)
* [`group`](#group)
* [`base_url`](#base_url)
* [`version`](#version)
* [`checksum`](#checksum)
* [`checksum_type`](#checksum_type)
* [`configuration_directory`](#configuration_directory)
* [`installation_directory`](#installation_directory)
* [`storage_root`](#storage_root)
* [`listen_ip`](#listen_ip)
* [`listen_port`](#listen_port)
* [`manage_service`](#manage_service)
* [`service_template`](#service_template)
* [`service_provider`](#service_provider)
* [`cert_directory`](#cert_directory)
* [`custom_configuration_file_path`](#custom_configuration_file_path)

##### <a name="package_ensure"></a>`package_ensure`

Data type: `Enum['present', 'absent']`

Decides if the `minio` binary will be installed.

Default value: `$minio::server::package_ensure`

##### <a name="owner"></a>`owner`

Data type: `String`

The user owning minio and its' files.

Default value: `$minio::server::owner`

##### <a name="group"></a>`group`

Data type: `String`

The group owning minio and its' files.

Default value: `$minio::server::group`

##### <a name="base_url"></a>`base_url`

Data type: `Stdlib::HTTPUrl`

Download base URL for the server. Can be used for local mirrors.

Default value: `$minio::server::base_url`

##### <a name="version"></a>`version`

Data type: `String`

Release version to be installed.

Default value: `$minio::server::version`

##### <a name="checksum"></a>`checksum`

Data type: `String`

Checksum for the binary.

Default value: `$minio::server::checksum`

##### <a name="checksum_type"></a>`checksum_type`

Data type: `String`

Type of checksum used to verify the binary being installed.

Default value: `$minio::server::checksum_type`

##### <a name="configuration_directory"></a>`configuration_directory`

Data type: `Stdlib::Absolutepath`

Directory holding Minio configuration file./minio`

Default value: `$minio::server::configuration_directory`

##### <a name="installation_directory"></a>`installation_directory`

Data type: `Stdlib::Absolutepath`

Target directory to hold the minio installation./minio`

Default value: `$minio::server::installation_directory`

##### <a name="storage_root"></a>`storage_root`

Data type: `Variant[Stdlib::Absolutepath, Array[Stdlib::Absolutepath]]`

Directory or directories where minio will keep all data.

Default value: `$minio::server::storage_root`

##### <a name="listen_ip"></a>`listen_ip`

Data type: `Stdlib::IP::Address`

IP address on which Minio should listen to requests.

Default value: `$minio::server::listen_ip`

##### <a name="listen_port"></a>`listen_port`

Data type: `Stdlib::Port`

Port on which Minio should listen to requests.

Default value: `$minio::server::listen_port`

##### <a name="manage_service"></a>`manage_service`

Data type: `Boolean`

Should we manage a server service definition for Minio?

Default value: `$minio::server::manage_service`

##### <a name="service_template"></a>`service_template`

Data type: `String`

Path to the server service template file.

Default value: `$minio::server::service_template`

##### <a name="service_provider"></a>`service_provider`

Data type: `String`

Which service provider do we use?

Default value: `$minio::server::service_provider`

##### <a name="cert_directory"></a>`cert_directory`

Data type: `Stdlib::Absolutepath`

Directory where minio will keep all cerfiticates.

Default value: `$minio::server::cert_directory`

##### <a name="custom_configuration_file_path"></a>`custom_configuration_file_path`

Data type: `Optional[Stdlib::Absolutepath]`

Optional custom location of the minio environment file.

Default value: `$minio::server::custom_configuration_file_path`

### <a name="minioserverservice"></a>`minio::server::service`

Copyright
---------

Copyright 2017-2021 Daniel S. Reichenbach <https://kogitoapp.com>

#### Examples

##### 

```puppet
class { 'minio::server::service':
    manage_service          => true,
    service_provider        => 'systemd',
    service_ensure          => 'running',
}
```

#### Parameters

The following parameters are available in the `minio::server::service` class:

* [`manage_service`](#manage_service)
* [`service_ensure`](#service_ensure)
* [`service_provider`](#service_provider)

##### <a name="manage_service"></a>`manage_service`

Data type: `Boolean`

Should we manage a server service definition for Minio?

Default value: `$minio::server::manage_service`

##### <a name="service_ensure"></a>`service_ensure`

Data type: `Stdlib::Ensure::Service`

Defines the state of the minio server service.

Default value: `$minio::server::service_ensure`

##### <a name="service_provider"></a>`service_provider`

Data type: `String`

Which service provider do we use?

Default value: `$minio::server::service_provider`

### <a name="minioserveruser"></a>`minio::server::user`

Copyright
---------

Copyright 2017-2021 Daniel S. Reichenbach <https://kogitoapp.com>

#### Examples

##### 

```puppet
class {'minio::server::user':
      manage_user  => true,
      manage_group => true,
      manage_home  => true,
      owner        => 'minio',
      group        => 'minio',
      home         => '/home/minio'
}
```

#### Parameters

The following parameters are available in the `minio::server::user` class:

* [`manage_user`](#manage_user)
* [`manage_group`](#manage_group)
* [`manage_home`](#manage_home)
* [`owner`](#owner)
* [`group`](#group)
* [`home`](#home)

##### <a name="manage_user"></a>`manage_user`

Data type: `Boolean`

Should we manage provisioning the user?

Default value: `$minio::server::manage_user`

##### <a name="manage_group"></a>`manage_group`

Data type: `Boolean`

Should we manage provisioning the group?

Default value: `$minio::server::manage_group`

##### <a name="manage_home"></a>`manage_home`

Data type: `Boolean`

Should we manage provisioning the home directory?

Default value: `$minio::server::manage_home`

##### <a name="owner"></a>`owner`

Data type: `String`

The user owning minio and its' files.

Default value: `$minio::server::owner`

##### <a name="group"></a>`group`

Data type: `String`

The group owning minio and its' files.

Default value: `$minio::server::group`

##### <a name="home"></a>`home`

Data type: `Optional[Stdlib::Absolutepath]`

Qualified path to the users' home directory.

Default value: `$minio::server::home`

## Resource types

### <a name="minio_client_alias"></a>`minio_client_alias`

**Autorequires**:
* `File[/root/.minioclient]`

#### Examples

##### 

```puppet
minio_client_alias { 'localminio':
  ensure              => 'present',
  endpoint            => 'http://localhost:9000',
  access_key          => 'admin',
  secret_key          => 'password',
  api_signature       => 'S3v4',
  path_lookup_support =>'on',
}
```

##### 

```puppet
minio_client_alias { 'default':
  ensure     => 'present',
  endpoint   => 'http://localhost:9000',
  access_key => 'admin',
  secret_key => Sensitive('password'),
}
```

#### Properties

The following properties are available in the `minio_client_alias` type.

##### `access_key`

Data type: `Optional[String]`

The API access key

##### `api_signature`

Data type: `Optional[Enum['S3v4', 'S3v2']]`

The API signature

##### `endpoint`

Data type: `String[1]`

The API endpoint url

##### `ensure`

Data type: `Enum[present, absent]`

Whether this resource should be present or absent on the target system.

Default value: `present`

##### `path_lookup_support`

Data type: `Optional[Enum['on', 'off', 'auto']]`

Indicate whether dns or path style url requests are supported by the server.

##### `secret_key`

Data type: `Optional[Variant[Sensitive[String], String]]`

The API access secret

#### Parameters

The following parameters are available in the `minio_client_alias` type.

* [`name`](#name)

##### <a name="name"></a>`name`

namevar

Data type: `String`

The name of the resource you want to manage.

